@@ -1,3 +1,5 @@
+import warnings
+
 try:  # Python 3
     import http.client as httplib
     from urllib.parse import parse_qsl
@@ -37,6 +39,7 @@ class QuickBooks(object):
     sandbox = False
     minorversion = None
     verifier_token = None
+    invoice_link = False
 
     sandbox_api_url_v3 = "https://sandbox-quickbooks.api.intuit.com/v3"
     api_url_v3 = "https://quickbooks.api.intuit.com/v3"
@@ -86,6 +89,8 @@ class QuickBooks(object):
         if 'minorversion' in kwargs:
             instance.minorversion = kwargs['minorversion']
 
+        instance.invoice_link = kwargs.get('invoice_link', False)
+
         if 'verifier_token' in kwargs:
             instance.verifier_token = kwargs.get('verifier_token')
 
@@ -111,6 +116,7 @@ class QuickBooks(object):
         """
         Disable use of singleton pattern.
         """
+        warnings.warn("disable_global deprecated", PendingDeprecationWarning)
         QuickBooks.__use_global = False
         QuickBooks.__instance = None
 
@@ -119,6 +125,7 @@ class QuickBooks(object):
         """
         Allow use of singleton pattern.
         """
+        warnings.warn("enable_global deprecated", PendingDeprecationWarning)
         QuickBooks.__use_global = True
 
     def _drop(self):
@@ -164,12 +171,18 @@ class QuickBooks(object):
         return result
 
     def make_request(self, request_type, url, request_body=None, content_type='application/json',
-                     params=None, file_path=None):
+                     params=None, file_path=None, request_id=None):
         if not params:
             params = {}
 
         if self.minorversion:
             params['minorversion'] = self.minorversion
+        
+        if request_id:
+            params['requestid'] = request_id
+
+        if self.invoice_link:
+            params['include'] = 'invoiceLink'
 
         if not request_body:
             request_body = {}
@@ -221,7 +234,8 @@ class QuickBooks(object):
         req = self.process_request(request_type, url, headers=headers, params=params, data=request_body)
 
         if req.status_code == httplib.UNAUTHORIZED:
-            raise exceptions.AuthorizationException("Application authentication failed", detail=req.text)
+            raise exceptions.AuthorizationException(
+                "Application authentication failed", error_code=req.status_code, detail=req.text)
 
         try:
             result = req.json()
@@ -291,11 +305,11 @@ class QuickBooks(object):
             else:
                 raise exceptions.QuickbooksException(message, code, detail)
 
-    def create_object(self, qbbo, request_body, _file_path=None):
+    def create_object(self, qbbo, request_body, _file_path=None, request_id=None):
         self.isvalid_object_name(qbbo)
 
         url = "{0}/company/{1}/{2}".format(self.api_url, self.company_id, qbbo.lower())
-        results = self.post(url, request_body, file_path=_file_path)
+        results = self.post(url, request_body, file_path=_file_path, request_id=request_id)
 
         return results
 
@@ -311,15 +325,15 @@ class QuickBooks(object):
 
         return True
 
-    def update_object(self, qbbo, request_body, _file_path=None):
+    def update_object(self, qbbo, request_body, _file_path=None, request_id=None):
         url = "{0}/company/{1}/{2}".format(self.api_url, self.company_id,  qbbo.lower())
-        result = self.post(url, request_body, file_path=_file_path)
+        result = self.post(url, request_body, file_path=_file_path, request_id=request_id)
 
         return result
 
-    def delete_object(self, qbbo, request_body, _file_path=None):
+    def delete_object(self, qbbo, request_body, _file_path=None, request_id=None):
         url = "{0}/company/{1}/{2}".format(self.api_url, self.company_id, qbbo.lower())
-        result = self.post(url, request_body, params={'operation': 'delete'}, file_path=_file_path)
+        result = self.post(url, request_body, params={'operation': 'delete'}, file_path=_file_path, request_id=request_id)
 
         return result
 
@@ -354,7 +368,8 @@ class QuickBooks(object):
 
             if response.status_code == httplib.UNAUTHORIZED:
                 # Note that auth errors have different result structure which can't be parsed by handle_exceptions()
-                raise exceptions.AuthorizationException("Application authentication failed", detail=response.text)
+                raise exceptions.AuthorizationException(
+                    "Application authentication failed", error_code=response.status_code, detail=response.text)
 
             try:
                 result = response.json()
