@@ -21,33 +21,38 @@ class UnsupportedException(QuickbooksException):
     """
     Quickbooks Error Codes from 500 to 599
     """
-    pass
+    def __str__(self):
+        return "QB Unsupported Exception: " + self.message + " \n\n" + self.detail
 
 
 class GeneralException(QuickbooksException):
     """
     Quickbooks Error Codes from 600 to 1999
     """
-    pass
+    def __str__(self):
+        return "QB General Exception: " + self.message + " \n\n" + self.detail
 
 
 class ValidationException(QuickbooksException):
     """
     Quickbooks Error Codes from 2000 to 4999
     """
-    pass
+    def __str__(self):
+        return "QB Validation Exception: " + self.message + " \n\n" + self.detail
 
 
 class SevereException(QuickbooksException):
     """
     Quickbooks Error Codes greater than 10000
     """
-    pass
+    def __str__(self):
+        return "QB Severe Exception: " + self.message + " \n\n" + self.detail
 
 
 class ObjectNotFoundException(QuickbooksException):
     """
     Quickbooks Error Code 610
     """
-    pass
+    def __str__(self):
+        return "QB Object Not Found Exception: " + self.message + " \n\n" + self.detail
 
